@@ -4,22 +4,23 @@ import datetime
 import os
 import subprocess
 
-VERSION = (1, 0, 3, 'final', 0)
+VERSION = (1, 1, 0, 'final', 0)
 
 
 def get_version(version=None):
     if version is None:
         version = VERSION
+
     assert len(version) == 5
     assert version[3] in ('alpha', 'beta', 'rc', 'final')
 
     # Now build the two parts of the version number:
     # main = X.Y[.Z]
     # sub = .devN - for pre-alpha releases
-    # | {a|b|c}N - for alpha, beta and rc releases
+    #  | {a|b|c}N - for alpha, beta and rc releases
 
     parts = 2 if version[2] == 0 else 3
-    main = '.'.join(str(x) for x in version[:parts])
+    main = '.'.join('{0}'.format(x) for x in version[:parts])
 
     sub = ''
     if version[3] == 'alpha' and version[4] == 0:
@@ -29,9 +30,10 @@ def get_version(version=None):
 
     elif version[3] != 'final':
         mapping = {'alpha': 'a', 'beta': 'b', 'rc': 'c'}
-        sub = mapping[version[3]] + str(version[4])
+        sub = '{0}{1}'.format(mapping[version[3]], version[4])
 
-    return main + sub
+    # see http://bugs.python.org/issue11638 - .encode('ascii')
+    return '{0}{1}'.format(main, sub)
 
 
 def get_mercurial_changeset():
