@@ -63,36 +63,47 @@ class ActiveModel(models.Model):
         collector.sort()
 
         # send pre_delete signals
-        for model, obj in collector.instances_with_model():
-            if not model._meta.auto_created:
-                signals.pre_delete.send(
-                    sender=model, instance=obj, using=using
-                )
+        def delete(collector):
+            for model, obj in collector.instances_with_model():
+                if not model._meta.auto_created:
+                    signals.pre_delete.send(
+                        sender=model, instance=obj, using=using
+                    )
 
-        # be compatible with django 1.4.x
-        if hasattr(collector, 'fast_deletes'):
-            # fast deletes
-            for qs in collector.fast_deletes:
-                for instance in qs:
-                    self._delete(instance)
+            # be compatible with django 1.4.x
+            if hasattr(collector, 'fast_deletes'):
+                # fast deletes
+                for qs in collector.fast_deletes:
+                    for instance in qs:
+                        self._delete(instance)
 
-        # delete batches
-        for model, batches in six.iteritems(collector.batches):
-            for field, instances in six.iteritems(batches):
+            # delete batches
+            # be compatible with django>=1.6
+            if hasattr(collector, 'batches'):
+                for model, batches in six.iteritems(collector.batches):
+                    for field, instances in six.iteritems(batches):
+                        for instance in instances:
+                            self._delete(instance)
+
+            # "delete" instances
+            for model, instances in six.iteritems(collector.data):
                 for instance in instances:
                     self._delete(instance)
 
-        # "delete" instances
-        for model, instances in six.iteritems(collector.data):
-            for instance in instances:
-                self._delete(instance)
+            # send post_delete signals
+            for model, obj in collector.instances_with_model():
+                if not model._meta.auto_created:
+                    signals.post_delete.send(
+                        sender=model, instance=obj, using=using
+                    )
 
-        # send post_delete signals
-        for model, obj in collector.instances_with_model():
-            if not model._meta.auto_created:
-                signals.post_delete.send(
-                    sender=model, instance=obj, using=using
-                )
+        # another django>=1.6 thing
+        try:
+            from django.db.transaction import commit_on_success_unless_managed
+        except ImportError:
+            delete(collector)
+        else:
+            commit_on_success_unless_managed(using=using)(delete(collector))
 
     delete.alters_data = True
 
