@@ -502,7 +502,7 @@ class TokenTests(TestCase):
             'access_token': token.secret
         }
         response = self.client.get(url, data)
-        token = Token.objects.get(pk=1)
+        token = Token.objects.get(pk=token.pk)
         self.assertNotEqual(token.modified, modified)
         self.assertEqual(response.content, "true")
 
