@@ -34,6 +34,11 @@ class UtilTests(TestCase):
         self.requests = patcher.start()
         self.addCleanup(patcher.stop)
 
+    def test_machine_id(self):
+        machine_id1 = machine_id()
+        machine_id2 = machine_id()
+        self.assertEqual(machine_id1, machine_id2)
+
     def test_shorthash(self):
         self.assertEqual(len(shorthash(self)), 10)
 
